Package: packFinder
Type: Package
Title: de novo Annotation of Pack-TYPE Transposable Elements
Version: 1.25.0
Authors@R: c(
    person(given = "Jack", 
           family = "Gisby", 
           role = c("aut", "cre"), 
           email = "jackgisby@gmail.com",
           comment = c(ORCID = "0000-0003-0511-8123")), 
    person(given = "Marco", 
           family = "Catoni", 
           role = "aut", 
           email="m.catoni@bham.ac.uk",
           comment = c(ORCID = "0000-0002-3258-2522"))
    )
Description: Algorithm and tools for in silico pack-TYPE transposon discovery. Filters a given genome for properties unique to DNA transposons and provides tools for the investigation of returned matches. Sequences are input in DNAString format, and ranges are returned as a dataframe (in the format returned by as.dataframe(GRanges)).
License: GPL-2
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: Biostrings, GenomicRanges, kmer, ape, methods, IRanges,
        S4Vectors
Suggests: biomartr, knitr, rmarkdown, testthat, dendextend, biocViews,
        BiocCheck, BiocStyle
RoxygenNote: 7.2.0
VignetteBuilder: knitr
URL: https://github.com/jackgisby/packFinder
BugReports: https://github.com/jackgisby/packFinder/issues
biocViews: Genetics, SequenceMatching, Annotation
git_url: https://git.bioconductor.org/packages/packFinder
git_branch: devel
git_last_commit: bf96429
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:12:21 UTC; biocbuild
Author: Jack Gisby [aut, cre] (ORCID: <https://orcid.org/0000-0003-0511-8123>),
  Marco Catoni [aut] (ORCID: <https://orcid.org/0000-0002-3258-2522>)
Maintainer: Jack Gisby <jackgisby@gmail.com>
